Learn R Programming

gompertztrunc (version 0.1.1)

bunmd_demo: Demo BUNMD Data Set

Description

A data set containing a sample of the CenSoc Berkeley Unified Numident Mortality Database (BUNMD) file, including age at death and select covariates.

Usage

bunmd_demo

Arguments

Format

A data frame with 81,002 rows and 6 variables:

ssn

Social Security number

bpl_string

Country of birth

death_age

Age at death (integer years)

byear

Calendar year of birth

dyear

Calendar year of death

age_first_application

Age at first Social Security application

Details

The Berkeley Unified Numident Mortality Database (BUNMD) is a cleaned and harmonized version of the NARA Numident file, consisting of the most informative parts of the 60+ application, claim, and death files released by the National Archives.The full data set of nearly 50 million records is available at https://censoc.berkeley.edu/data/.