Learn R Programming

gompertztrunc (version 0.1.1)

get.par.start: Get starting values for parameters

Description

Uses linear modeling to compute initial values for MLE optimizer

Usage

get.par.start(formula, data)

Value

Named vector of initial parameter estimates

Arguments

formula

the estimation formula

data

data matrix with y, u, l, and covariates, including cohort